"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Bus = void 0;
var Bus = /** @class */ (function () {
    function Bus() {
        this.callbacks = [];
        this.subscriptionCount = 0;
    }
    Bus.prototype.getSubscriptionCount = function () {
        return this.subscriptionCount;
    };
    Bus.prototype.publish = function (message) {
        for (var i = 0; i < this.callbacks.length; i++) {
            this.callbacks[i](message);
        }
    };
    Bus.prototype.subscribe = function (subscription) {
        var _this = this;
        var wrappedCallback = this.wrapCallback(subscription);
        this.callbacks.push(wrappedCallback);
        this.subscriptionCount++;
        return {
            unsubscribe: function () { _this.unsubscribe(wrappedCallback); }
        };
    };
    Bus.prototype.unsubscribeAll = function () {
        this.callbacks = [];
        this.subscriptionCount = 0;
    };
    Bus.prototype.unsubscribe = function (callback) {
        var callbacks = this.callbacks;
        var index = callbacks.indexOf(callback);
        if (index > -1) {
            callbacks.splice(index, 1);
            this.subscriptionCount--;
        }
    };
    Bus.prototype.wrapCallback = function (subscription) {
        var safeCallback = function (message) {
            try {
                subscription.callback(message);
            }
            catch (callbackError) {
                if (!subscription.errorHandler) {
                    return;
                }
                try {
                    subscription.errorHandler(callbackError);
                }
                catch (error) {
                    throw ({ callbackError: callbackError, errorHandlerError: error });
                }
            }
        };
        return function (message) {
            if (subscription.delay === undefined) {
                safeCallback(message);
            }
            else {
                setTimeout(function () { safeCallback(message); }, subscription.delay);
            }
        };
    };
    return Bus;
}());
exports.Bus = Bus;
