import { Message } from "./message";
import { Subscriber, Subscription } from "./subscription";
export declare class Post {
    private static instance;
    private buses;
    private constructor();
    /**
     * Get or initialize the singleton instance of Post
     *
     * @return {Post} the instance of Post
     */
    static get getInstance(): Post;
    /**
     * Create a new Bus with the given name (if none with the same name exists already)
     *
     * @param {string} busName The Bus name
     */
    createBus(busName: string): void;
    /**
     * Get the number of active subscribers for a given Bus
     *
     * @param {string} busName The Bus name
     * @return {number} The number of active subscription to the bus
     */
    getBusSubscriptionCount(busName: string): number | undefined;
    /**
     * Remove a given Bus
     *
     * @param {string} busName The Bus name
     */
    removeBus(busName: string): void;
    /**
     * Reset a give Bus (unsubscribe all subscribers)
     *
     * @param {string} busName The Bus name
     */
    resetBus(busName: string): void;
    /**
     * Publish a Message into a given Bus
     *
     * @param {string} busName The Bus name
     * @param {Message} message The message to send into the Bus
     */
    publish(busName: string, message: Message): void;
    /**
     * Reinitialize Post (all buses will be deleted, `default` bus will be recreated)
     */
    reinitialize(): void;
    /**
     * Subscribe to a given Bus
     *
     * @param {string} busName The Bus name
     * @param {Subscription} subscription The subscription to the Bus
     * @return {Subscriber} The subscriber
     */
    subscribe(busName: string, subscription: Subscription): Subscriber;
    private initialize;
}
