"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Post = void 0;
var bus_1 = require("./bus");
var Post = /** @class */ (function () {
    function Post() {
        this.buses = new Map();
        this.initialize();
    }
    Object.defineProperty(Post, "getInstance", {
        /**
         * Get or initialize the singleton instance of Post
         *
         * @return {Post} the instance of Post
         */
        get: function () {
            return this.instance || (this.instance = new this());
        },
        enumerable: false,
        configurable: true
    });
    /**
     * Create a new Bus with the given name (if none with the same name exists already)
     *
     * @param {string} busName The Bus name
     */
    Post.prototype.createBus = function (busName) {
        if (!this.buses.has(busName)) {
            this.buses.set(busName, new bus_1.Bus());
        }
    };
    /**
     * Get the number of active subscribers for a given Bus
     *
     * @param {string} busName The Bus name
     * @return {number} The number of active subscription to the bus
     */
    Post.prototype.getBusSubscriptionCount = function (busName) {
        var _a;
        return (_a = this.buses.get(busName)) === null || _a === void 0 ? void 0 : _a.getSubscriptionCount();
    };
    /**
     * Remove a given Bus
     *
     * @param {string} busName The Bus name
     */
    Post.prototype.removeBus = function (busName) {
        this.buses.delete(busName);
    };
    /**
     * Reset a give Bus (unsubscribe all subscribers)
     *
     * @param {string} busName The Bus name
     */
    Post.prototype.resetBus = function (busName) {
        var _a;
        (_a = this.buses.get(busName)) === null || _a === void 0 ? void 0 : _a.unsubscribeAll();
    };
    /**
     * Publish a Message into a given Bus
     *
     * @param {string} busName The Bus name
     * @param {Message} message The message to send into the Bus
     */
    Post.prototype.publish = function (busName, message) {
        var _a;
        (_a = this.buses.get(busName)) === null || _a === void 0 ? void 0 : _a.publish(message);
    };
    /**
     * Reinitialize Post (all buses will be deleted, `default` bus will be recreated)
     */
    Post.prototype.reinitialize = function () {
        this.initialize();
    };
    /**
     * Subscribe to a given Bus
     *
     * @param {string} busName The Bus name
     * @param {Subscription} subscription The subscription to the Bus
     * @return {Subscriber} The subscriber
     */
    Post.prototype.subscribe = function (busName, subscription) {
        var _a, _b;
        return (_b = (_a = this.buses.get(busName)) === null || _a === void 0 ? void 0 : _a.subscribe(subscription)) !== null && _b !== void 0 ? _b : { unsubscribe: function () { return undefined; } };
    };
    Post.prototype.initialize = function () {
        this.buses = new Map();
        this.buses.set('default', new bus_1.Bus());
    };
    return Post;
}());
exports.Post = Post;
